@@ -1,8 +1,9 @@
-import subprocess
+
 
 from e2e_cli.core.error_logs_service import action_on_exception
 from e2e_cli.core.helper_service import Checks
 from e2e_cli.core.py_manager import Py_version_manager
+from e2e_cli.core import help_messages
 
 from e2e_cli.config.config_routing import ConfigRouting
 from e2e_cli.loadbalancer.lb_routing import LBRouting
@@ -22,32 +23,17 @@ class CommandsRouting:
 
     def route(self):
         if self.arguments.alias is None:
-                Py_version_manager.py_print( "usage: e2e_cli {doc, alias, @<alias>}")
-                Py_version_manager.py_print()
-                Py_version_manager.py_print("E2E CLI")
-                Py_version_manager.py_print()
-                Py_version_manager.py_print( "Commands/Options:")
-                Py_version_manager.py_print( "    doc                 To view detailed man doc")
-                Py_version_manager.py_print( "    alias               To add/delete api key and auth tokens")
-                Py_version_manager.py_print( "    @<alias>            To access services using CLI")
+                help_messages.e2e_help()
 
 
-        elif self.arguments.alias == "doc":
+        elif self.arguments.alias == "help" or self.arguments.alias == "doc":
                 man_page()
 
 
         elif (self.arguments.alias == "alias") :
 
             if(self.arguments.command not in ["add", "view","add_file","delete"]):
-                Py_version_manager.py_print( "usage: e2e_cli alias {add, view, add_file, delete}")
-                Py_version_manager.py_print()
-                Py_version_manager.py_print("E2E CLI")
-                Py_version_manager.py_print()
-                Py_version_manager.py_print( "alias commands:")
-                Py_version_manager.py_print( "    add                 To add api key and auth token")
-                Py_version_manager.py_print( "    add_file            To add api key and auth token via file")
-                Py_version_manager.py_print( "    view                To view a list of tokens")
-                Py_version_manager.py_print( "    delete              To add delete api key and auth token")
+                help_messages.e2e_alias_help()  
 
             elif self.arguments.command in ["add", "view", "add_file", "delete"]:
                 try:
@@ -61,7 +47,8 @@ class CommandsRouting:
 
             if (self.arguments.command is None):
                 Py_version_manager.py_print("issue in command/Wrong command given!!")
-                subprocess.call(['e2e_cli', 'alias','-h'])
+                help_messages.e2e_service_help()
+                # subprocess.call(['e2e_cli', 'alias','-h'])
 
             elif self.arguments.command == "node":
                 try:
@@ -128,6 +115,6 @@ class CommandsRouting:
                             
         else :
               Py_version_manager.py_print("Command not found")
-              Py_version_manager.py_print("Did you mean, e2e_cli doc --> for viewing man doc ??")
+              Py_version_manager.py_print("Did you mean, e2e_cli help/doc --> for viewing man doc ??")
               Py_version_manager.py_print("Did you mean, e2e_cli alias [command] --> for adding alias ??")
               Py_version_manager.py_print("Did you mean, e2e_cli @<alias> [command] [sub-command] --> for accessing services ??")
\ No newline at end of file
