@@ -49,9 +49,7 @@ class AuthConfig:
 
     def reserve_keyword_check(self):
         if(str(self.kwargs["alias"]).lower() in RESERVES):
-                Py_version_manager.py_print("The used alias name is a reserve keyword for cli tool")
-        elif((self.kwargs["alias"])==None):
-                Py_version_manager.py_print("incorrect format, add @ before alias name")            
+                Py_version_manager.py_print("The used alias name is a reserve keyword for cli tool")            
         else:
                 self.add_json_to_file()
 
