@@ -12,7 +12,7 @@ class DBaaSRouting:
 
     def route(self):
         if (self.arguments.dbaas_commands is None) and (self.arguments.action is None):
-            subprocess.call(['e2e_cli', 'dbaas', '-h'])
+            subprocess.call(['e2e_cli', "alias",'dbaas', '-h'])
 
         elif (self.arguments.dbaas_commands is not None) and (self.arguments.action is not None):
               Py_version_manager.py_print("Only one action at a time !!")
