@@ -1,9 +1,11 @@
 import argparse
-from functools import reduce
+# import argcomplete working on auto-complete now 
 
 from e2e_cli.commands_routing import CommandsRouting
 from e2e_cli.core.error_logs_service import ErrorLogs
-from e2e_cli.core.py_manager import Py_version_manager, cli_formatter
+from e2e_cli.core.py_manager import Py_version_manager
+from e2e_cli.core import help_messages
+
 
 class Main:
     def __init__(self):
@@ -29,10 +31,10 @@ class Main:
     def node(self, parser):
         node_sub_parser = parser.add_subparsers(title="node Commands", dest="node_commands")
         node_action=parser.add_argument('-action', '--action', help="Type of action to be performed your node")
-        node_create_sub_parser = node_sub_parser.add_parser("create", help="To create a new node", formatter_class=cli_formatter())
-        node_delete_sub_parser = node_sub_parser.add_parser("delete", help="To delete a specific node", formatter_class=cli_formatter())
-        node_list_sub_parser = node_sub_parser.add_parser("list", help="To get a list of all nodes", formatter_class=cli_formatter())
-        node_get_sub_parser = node_sub_parser.add_parser("get", help="To get a list of all nodes", formatter_class=cli_formatter())
+        node_create_sub_parser = node_sub_parser.add_parser("create", help="To create a new node", formatter_class=help_messages.cli_formatter())
+        node_delete_sub_parser = node_sub_parser.add_parser("delete", help="To delete a specific node", formatter_class=help_messages.cli_formatter())
+        node_list_sub_parser = node_sub_parser.add_parser("list", help="To get a list of all nodes", formatter_class=help_messages.cli_formatter())
+        node_get_sub_parser = node_sub_parser.add_parser("get", help="To get a list of all nodes", formatter_class=help_messages.cli_formatter())
         self.FormatUsageCommand(node_action, "node", "actions")
         self.FormatUsageCommand(node_create_sub_parser, "node", "create")
         self.FormatUsageCommand(node_delete_sub_parser, "node", "delete")
@@ -54,10 +56,10 @@ class Main:
 
     def lb(self, parser):
         node_sub_parser = parser.add_subparsers(title="LB Commands", dest="lb_commands")
-        node_create_sub_parser = node_sub_parser.add_parser("create", help="To create a new node", formatter_class=cli_formatter())
-        node_delete_sub_parser = node_sub_parser.add_parser("delete", help="To delete a specific node", formatter_class=cli_formatter())
-        node_list_sub_parser = node_sub_parser.add_parser("list", help="To get a list of all nodes", formatter_class=cli_formatter())
-        node_edit_sub_parser = node_sub_parser.add_parser("edit", help="To get a list of all nodes", formatter_class=cli_formatter())
+        node_create_sub_parser = node_sub_parser.add_parser("create", help="To create a new node", formatter_class=help_messages.cli_formatter())
+        node_delete_sub_parser = node_sub_parser.add_parser("delete", help="To delete a specific node", formatter_class=help_messages.cli_formatter())
+        node_list_sub_parser = node_sub_parser.add_parser("list", help="To get a list of all nodes", formatter_class=help_messages.cli_formatter())
+        node_edit_sub_parser = node_sub_parser.add_parser("edit", help="To get a list of all nodes", formatter_class=help_messages.cli_formatter())
         self.FormatUsageCommand(node_create_sub_parser, "node", "create")
         self.FormatUsageCommand(node_delete_sub_parser, "node", "delete")
         self.FormatUsageCommand(node_list_sub_parser, "node", "list")
@@ -127,9 +129,22 @@ class Main:
 
 
 class ArgPaser(argparse.ArgumentParser):
+
+    def version_and_pkg_info(self, msg):
+        if("argument -v/--version: expected one argument"==msg):
+            help_messages.e2e_version_info()
+            self.exit()
+
+        if("argument --info: expected one argument"==msg):
+            help_messages.e2e_pakage_info()
+            self.exit()
+
+
     def error(self, message):
         args = {'prog': self.prog, 'message': message}
-        Py_version_manager.py_print( args["message"])
+        self.version_and_pkg_info(args["message"])
+        if("unrecognized arguments: -h" not in args["message"]):
+                        Py_version_manager.py_print( args["message"])
 
 
 def commanding(parser):
@@ -171,8 +186,10 @@ def commanding(parser):
 
 
 def run_main_class():
-    parser = ArgPaser(description="E2E CLI", formatter_class=cli_formatter())
-    parser.add_argument("alias", type=str, help="The name of your API access credentials")
+    parser = ArgPaser(description="E2E CLI", formatter_class=help_messages.cli_formatter(), add_help=False)
+    parser.add_argument("-v", "--version", default=False)
+    parser.add_argument( "--info", default=False)
+    parser.add_argument("alias", metavar="option", type=str, help="The option to be used or name of your access credentials valid option")
     commanding(parser)
 
     args = parser.parse_args()
