@@ -54,7 +54,7 @@ class NodeCrud:
         if (my_payload.Option=="auto"):
                         user_agent='cli_python'
         else:
-                user_agent='e2e-cli'
+                user_agent='cli-e2e'
         my_payload=my_payload.__dict__
         my_payload.pop('Option')
 
