@@ -3,6 +3,7 @@ from prettytable import PrettyTable
 from e2e_cli.core.py_manager import Py_version_manager
 from e2e_cli.core.alias_service import get_user_cred
 from e2e_cli.core.request_service import Request
+from e2e_cli.core.constants import BASE_URL
 
 
 class Nodelisting:
@@ -13,7 +14,7 @@ class Nodelisting:
 
 
     def node_listing(self):
-        url= "https://api.e2enetworks.com/myaccount/api/v1/images/category-list/?apikey=" +self.API_key+ "&contact_person_id=null&location=Delhi"
+        url =  BASE_URL+"myaccount/api/v1/images/category-list/?apikey=" +self.API_key+ "&contact_person_id=null&location=Delhi"
         req= "GET"
         my_payload={}
         response= Request(url, self.Auth_Token, my_payload, req, user_agent='cli_python').response.json()['data']
@@ -67,7 +68,7 @@ class Nodelisting:
       
       
 
-        url= "https://api.e2enetworks.com/myaccount/api/v1/images/?apikey="+ self.API_key+"&contact_person_id=null&display_category="+node_type1 +"&category="+Os_type +"&osversion="+Os_version +"&gpu_type=&ng_container=null&os="+Os_type +"&location=Delhi"
+        url =  BASE_URL+"myaccount/api/v1/images/?apikey="+ self.API_key+"&contact_person_id=null&display_category="+node_type1 +"&category="+Os_type +"&osversion="+Os_version +"&gpu_type=&ng_container=null&os="+Os_type +"&location=Delhi"
         req= "GET"
         my_payload={}
         response= Request(url, self.Auth_Token, my_payload, req, user_agent='cli_python').response.json()['data']
